#[non_exhaustive]pub enum OpenVolume<'a, S>where
S: Seek,{
Fat(FatVolume<Borrowed<'a, S>>),
}Expand description
An asynchronously opened block filesystem with concrete-format access.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl<'a, S> OpenVolume<'a, S>
impl<'a, S> OpenVolume<'a, S>
Sourcepub async fn open(source: &'a mut S, logical_block_size: u32) -> Result<Self>
pub async fn open(source: &'a mut S, logical_block_size: u32) -> Result<Self>
Asynchronously detects and opens a filesystem at the start of source.
Partitioned disks must first be narrowed to a partition view.
Sourcepub async fn open_detected(
source: &'a mut S,
detected: FatVariant,
) -> Result<Self>
pub async fn open_detected( source: &'a mut S, detected: FatVariant, ) -> Result<Self>
Asynchronously opens a previously detected FAT variant.
Sourcepub fn format(&self) -> FatVariant
pub fn format(&self) -> FatVariant
Returns the concrete FAT variant of the opened filesystem.
Sourcepub fn as_fat_mut(&mut self) -> Option<&mut FatVolume<Borrowed<'a, S>>>
pub fn as_fat_mut(&mut self) -> Option<&mut FatVolume<Borrowed<'a, S>>>
Mutably borrows the opened FAT filesystem.
Sourcepub fn into_fat(self) -> Result<FatVolume<Borrowed<'a, S>>, Self>
pub fn into_fat(self) -> Result<FatVolume<Borrowed<'a, S>>, Self>
Extracts the FAT filesystem, returning self if its format differs.
Sourcepub fn into_inner(self) -> &'a mut S
pub fn into_inner(self) -> &'a mut S
Closes the filesystem and returns the borrowed source.